@@ -5,8 +5,9 @@ import json
 import click
 import yaml
 
-import osxphotos
+from osxphotos import PhotosDB, iPhotoDB
 from osxphotos._constants import _PHOTOS_4_VERSION
+from osxphotos.iphoto import is_iphoto_library
 
 from .cli_params import DB_ARGUMENT, DB_OPTION, JSON_OPTION
 from .common import get_photos_db
@@ -22,14 +23,18 @@ from .list import _list_libraries
 def info(ctx, cli_obj, db, json_, photos_library):
     """Print out descriptive info of the Photos library database."""
 
-    db = get_photos_db(*photos_library, db, cli_obj.db)
+    # needed for to make CliRunner work for testing
+    cli_db = cli_obj.db if cli_obj is not None else None
+    db = get_photos_db(*photos_library, db, cli_db)
     if db is None:
         click.echo(ctx.obj.group.commands["info"].get_help(ctx), err=True)
         click.echo("\n\nLocated the following Photos library databases: ", err=True)
         _list_libraries()
         return
 
-    photosdb = osxphotos.PhotosDB(dbfile=db)
+    click.echo(f"Loading library: {db}", err=True)
+
+    photosdb = iPhotoDB(db) if is_iphoto_library(db) else PhotosDB(dbfile=db)
     info = {"database_path": photosdb.db_path, "database_version": photosdb.db_version}
     photos = photosdb.photos(movies=False)
     not_shared_photos = [p for p in photos if not p.shared]
@@ -67,7 +72,7 @@ def info(ctx, cli_obj, db, json_, photos_library):
     info["persons_count"] = len(persons)
     info["persons"] = persons
 
-    if cli_obj.json or json_:
+    if json_ or (cli_obj and cli_obj.json):
         click.echo(json.dumps(info, ensure_ascii=False))
     else:
         click.echo(yaml.dump(info, sort_keys=False, allow_unicode=True))
