@@ -1,4 +1,7 @@
 """Click parameter types for osxphotos CLI"""
+
+from __future__ import annotations
+
 import datetime
 import os
 import pathlib
@@ -18,6 +21,8 @@ from osxphotos.utils import expand_and_validate_filepath, load_function
 
 __all__ = [
     "BitMathSize",
+    "BooleanString",
+    "CSVOptions",
     "DateOffset",
     "DateTimeISO8601",
     "DeprecatedPath",
@@ -68,7 +73,6 @@ class PathOrStdin(click.Path):
 
 
 class DateTimeISO8601(click.ParamType):
-
     name = "DATETIME"
 
     def convert(self, value, param, ctx):
@@ -82,7 +86,6 @@ class DateTimeISO8601(click.ParamType):
 
 
 class BitMathSize(click.ParamType):
-
     name = "BITMATH"
 
     def convert(self, value, param, ctx):
@@ -102,7 +105,6 @@ class BitMathSize(click.ParamType):
 
 
 class TimeISO8601(click.ParamType):
-
     name = "TIME"
 
     def convert(self, value, param, ctx):
@@ -141,7 +143,6 @@ class FunctionCall(click.ParamType):
 
 
 class ExportDBType(click.ParamType):
-
     name = "EXPORTDB"
 
     def convert(self, value, param, ctx):
@@ -279,7 +280,6 @@ class StrpDateTimePattern(click.ParamType):
 
 
 class Latitude(click.ParamType):
-
     name = "Latitude"
 
     def convert(self, value, param, ctx):
@@ -295,7 +295,6 @@ class Latitude(click.ParamType):
 
 
 class Longitude(click.ParamType):
-
     name = "Longitude"
 
     def convert(self, value, param, ctx):
@@ -308,3 +307,46 @@ class Longitude(click.ParamType):
             self.fail(
                 f"Invalid longitude {value}. Must be a floating point number between -180 and 180."
             )
+
+
+class BooleanString(click.ParamType):
+    """A boolean string in the format True/False, Yes/No, T/F, Y/N, 1/0 (case insensitive)"""
+
+    name = "BooleanString"
+
+    def convert(self, value, param, ctx):
+        if value.lower() in ["true", "yes", "t", "y", "1"]:
+            return True
+        elif value.lower() in ["false", "no", "f", "n", "0"]:
+            return False
+        else:
+            self.fail(
+                f"Invalid boolean string {value}. Must be one of True/False, Yes/No, T/F, Y/N, 1/0 (case insensitive)."
+            )
+
+
+class CSVOptions(click.ParamType):
+    """A comma-separated list of option values, not case sensitive"""
+
+    name = "CSVOptions"
+
+    def __init__(self, options: list[str]):
+        """Initialize CSVOptions
+
+        Args:
+            options: list of valid options as str
+
+        Note:
+            The convert method returns a tuple[str, ...] of the options selected
+        """
+        self._csv_options = options
+
+    def convert(self, value, param, ctx) -> tuple[str, ...]:
+        values = value.split(",")
+        values = [v.lower().strip() for v in values]
+        for v in values:
+            if v not in self._csv_options:
+                self.fail(
+                    f"Invalid option {v}. Must be one or more (separated by comma) of {','.join(self._csv_options)}"
+                )
+        return tuple(values)
