@@ -7,7 +7,6 @@ from functools import partial
 from textwrap import dedent
 
 import click
-from photoscript import PhotosLibrary
 from rich.console import Console
 
 from osxphotos._constants import APP_NAME
@@ -25,10 +24,16 @@ from osxphotos.photodates import (
     update_photo_from_function,
     update_photo_time_for_new_timezone,
 )
-from osxphotos.photosalbum import PhotosAlbumPhotoScript
 from osxphotos.phototz import PhotoTimeZone, PhotoTimeZoneUpdater
+from osxphotos.platform import assert_macos
 from osxphotos.utils import noop, pluralize
 
+assert_macos()
+
+from photoscript import PhotosLibrary
+
+from osxphotos.photosalbum import PhotosAlbumPhotoScript
+
 from .cli_params import THEME_OPTION, TIMESTAMP_OPTION, VERBOSE_OPTION
 from .click_rich_echo import rich_click_echo as echo
 from .click_rich_echo import rich_echo_error as echo_error
@@ -164,7 +169,7 @@ See also `osxphotos help timewarp` for more information on the timewarp
 command which can be used to change the time zone of photos after import.
 
 
-"""
+"""  # noqa: E501
                 ),
                 width=formatter.width,
                 markdown=True,
@@ -262,6 +267,9 @@ command which can be used to change the time zone of photos after import.
     "Requires the third-party exiftool utility be installed (see https://exiftool.org/). "
     "Using this option modifies the *original* file of the image in your Photos library. "
     "--push-exif will be executed after any other updates are performed on the photo. "
+    "Note that if the Photos library is synced to iCloud, the updated EXIF data will not be"
+    "synced to iCloud and thus exporting the photo on any other device will not show the updated EXIF data. "
+    "This option is most useful for libraries that are not synced to iCloud. "
     "See also --pull-exif.",
 )
 @click.option(
